/// <reference types="react" />
import { ConnectWalletDetailsProps } from "./ConnectWalletDetails/WalletDetailsButton";
import { ConnectWalletButtonProps } from "./ConnectWalletFlow/ConnectWalletButton";
import { SupportedTokens } from "./SendFunds/defaultTokens";
export type ConnectWalletProps = {
    /**
     * Renders a custom button to display the connected wallet details instead of the default button
     */
    detailsButton?: ConnectWalletDetailsProps["detailsButton"];
    /**
     * Renders custom rows in the Connect Wallet Details modal
     */
    extraRows?: ConnectWalletDetailsProps["extraRows"];
    /**
     * Option to hide the Send button in the wallet details modal.
     *
     * The default is `false`
     */
    hideSendButton?: boolean;
    /**
     * Option to hide the Receive button in the wallet details modal.
     *
     * The default is `false`
     */
    hideReceiveButton?: boolean;
    /**
     * Hide option to request testnet funds for testnets in dropdown
     *
     * By default it is `true`, If you want to show the "Request Testnet funds" link when user is connected to a testnet, set this prop to `false`
     *
     * @example
     * ```tsx
     * <ConnectWallet hideTestnetFaucet={false} />
     * ```
     */
    hideTestnetFaucet?: boolean;
    /**
     * Whether to show "Switch Network" button if the wallet is connected,
     * but it is not connected to the `activeChain` provided in [`ThirdwebProvider`](https://portal.thirdweb.com/react-native/v0/ThirdwebProvider)
     *
     * Please, note that if you support multiple networks in your app this prop should
     * be set to `false` to allow users to switch between networks.
     *
     * The default is `false`
     */
    switchToActiveChain?: boolean;
    /**
     * Override the default supported tokens for each network
     *
     * These tokens will be displayed in "Send Funds" Modal
     */
    supportedTokens?: SupportedTokens;
    /**
     * Display the balance of a token instead of the native token in ConnectWallet details button.
     *
     * @example
     * ```tsx
     * import { Base } from "@thirdweb-dev/chains";
     *
     * <ConnectWallet balanceToken={{
     *    1: "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599" // show USDC balance when connected to Ethereum mainnet
     *    [Base.chainId]: "0x50c5725949A6F0c72E6C4a641F24049A917DB0Cb", // show Dai stablecoin token balance when connected to Base mainnet
     *  }}
     * />
     * ```
     */
    displayBalanceToken?: Record<number, string>;
    /**
     * Hide the "switch to Personal wallet" option in the wallet modal which is shown when wallet is connected to a Smart Wallet
     *
     * The default is `false`
     */
    hideSwitchToPersonalWallet?: boolean;
    /**
     * Hide the "Disconnect Wallet" button in the ConnectWallet Dropdown.
     *
     * By default it is `false`
     *
     * @example
     * ```tsx
     * <ConnectWallet hideDisconnect={true} />
     * ```
     */
    hideDisconnect?: boolean;
} & ConnectWalletButtonProps;
export declare const ConnectWallet: ({ detailsButton, theme, buttonTitle, modalTitle, modalTitleIconUrl, hideReceiveButton, hideSendButton, extraRows, hideTestnetFaucet, displayBalanceToken, switchToActiveChain, termsOfServiceUrl, privacyPolicyUrl, supportedTokens, hideSwitchToPersonalWallet, hideDisconnect, }: ConnectWalletProps) => import("react").JSX.Element;
