import Text from "../base/Text";
import { ChooseWallet } from "./ChooseWallet/ChooseWallet";
import { ConnectingWallet } from "./ConnectingWallet/ConnectingWallet";
import { useAddress, useWalletContext, useWallets, } from "@thirdweb-dev/react-core";
import { useCallback, useEffect, useState } from "react";
import { walletIds } from "@thirdweb-dev/wallets";
import { useColorScheme } from "react-native";
import { useGlobalTheme, useLocale, useUIContext, } from "../../providers/ui-context-provider";
import { CLOSE_MODAL_STATE } from "../../utils/modalTypes";
import Box from "../base/Box";
import { ThemeProvider } from "../../styles/ThemeProvider";
export const ConnectEmbed = (props) => {
    return (<ConnectEmbedUI container={{
            borderRadius: "xxl",
            paddingBottom: "lg",
        }} {...props} isModal={false}/>);
};
export const ConnectEmbedUI = ({ modalTitle, modalTitleIconUrl, privacyPolicyUrl, termsOfServiceUrl, isModal = true, theme, container: container, onConnect, }) => {
    const l = useLocale();
    const supportedWallets = useWallets();
    const setModalState = useUIContext().setModalState;
    const walletConfig = supportedWallets.length === 1 ? supportedWallets[0] : undefined;
    const [modalVisible, setModalVisible] = useState(false);
    const [activeWallet, setActiveWallet] = useState();
    const [isConnecting, setIsConnecting] = useState(false);
    const [selectionData, setSelectionData] = useState();
    const colorTheme = useColorScheme();
    const appTheme = useGlobalTheme();
    const setTheme = useUIContext().setTheme;
    const address = useAddress();
    const { activeWallet: connectedWallet, setConnectedWallet, setConnectionStatus, connectionStatus, connect, createWalletInstance, } = useWalletContext();
    const onClose = useCallback((reset) => {
        setModalState(CLOSE_MODAL_STATE("ConnectWalletFlow"));
        if (reset) {
            resetModal();
        }
    }, [setModalState]);
    const connectActiveWallet = useCallback(async (wallet, data) => {
        setIsConnecting(true);
        try {
            await connect(wallet, { ...data });
            onConnect?.();
        }
        catch (error) {
            console.error("Error connecting to the wallet", error);
        }
        finally {
            onClose(true);
        }
    }, [connect, onClose, onConnect]);
    const onChooseWallet = useCallback((wallet, data) => {
        setSelectionData(data);
        setActiveWallet(wallet);
        // If the wallet has no custom connect UI, then connect it
        if (!wallet.connectUI) {
            connectActiveWallet(wallet, data);
        }
    }, [connectActiveWallet]);
    useEffect(() => {
        if (theme) {
            setTheme(theme);
        }
    }, [setTheme, theme]);
    useEffect(() => {
        // case when only one wallet is passed in supportedWallets
        if (walletConfig) {
            // if there's a selection UI, then continue with the flow
            if (walletConfig.selectUI) {
                return;
            }
            if (walletConfig.connectUI) {
                // if there's a connection UI and no selection UI, then show it
                setActiveWallet(walletConfig);
                return;
            }
            // if there's no connection UI or selectionUI, then automatically select it
            onChooseWallet(walletConfig);
        }
    }, [onChooseWallet, walletConfig]);
    const onOpenModal = () => {
        setModalVisible(true);
    };
    const onBackPress = useCallback(() => {
        resetModal();
    }, []);
    const resetModal = () => {
        setActiveWallet(undefined);
        setIsConnecting(false);
    };
    const handleClose = useCallback(() => {
        onClose(true);
    }, [onClose]);
    const getComponentForWallet = useCallback(() => {
        if (activeWallet?.connectUI) {
            return (<activeWallet.connectUI modalSize="compact" theme={colorTheme || "dark"} goBack={onBackPress} connected={handleClose} isOpen={modalVisible} show={onOpenModal} hide={handleClose} walletConfig={activeWallet} supportedWallets={supportedWallets} selectionData={selectionData} setSelectionData={() => { }} // TODO
             connect={(options) => {
                    return connect(activeWallet, options);
                }} connectedWallet={connectedWallet} connectedWalletAddress={address} connectionStatus={connectionStatus} createWalletInstance={() => createWalletInstance(activeWallet)} setConnectedWallet={setConnectedWallet} setConnectionStatus={setConnectionStatus}/>);
        }
    }, [
        activeWallet,
        address,
        connect,
        connectedWallet,
        connectionStatus,
        createWalletInstance,
        handleClose,
        modalVisible,
        onBackPress,
        selectionData,
        setConnectedWallet,
        setConnectionStatus,
        supportedWallets,
        colorTheme,
    ]);
    return (<ThemeProvider theme={appTheme}>
      <Box flexDirection="column" backgroundColor="background" {...container}>
        {activeWallet ? (isConnecting ? (<ConnectingWallet subHeaderText="" content={activeWallet.id === walletIds.localWallet ? (<Text variant="bodySmallSecondary" mt="md" textAlign="center">
                    {l.connecting_wallet.creating_encrypting}
                  </Text>) : undefined} wallet={activeWallet} onClose={isModal ? onClose : undefined} onBackPress={onBackPress}/>) : (getComponentForWallet())) : (<ChooseWallet headerText={modalTitle} modalTitleIconUrl={modalTitleIconUrl} privacyPolicyUrl={privacyPolicyUrl} termsOfServiceUrl={termsOfServiceUrl} wallets={supportedWallets} onChooseWallet={onChooseWallet} onClose={isModal ? onClose : undefined}/>)}
      </Box>
    </ThemeProvider>);
};
