import { deepMerge } from "../types/deepPartial";
import { _en } from "./en";
import { _es } from "./es";
import { _tl } from "./tl";
import { _ja } from "./ja";
import { _tr } from "./tr";
const locales = { en: _en, es: _es, ja: _ja, tl: _tl, tr: _tr };
/**
 * @internal
 */
export const setLocale = (locale) => {
    if (typeof locale === "string") {
        const selectedLocale = locales[locale];
        if (!selectedLocale) {
            throw new Error(`Locale ${locale} not supported`);
        }
        return selectedLocale;
    }
    return locale;
};
/**
 * @internal
 */
export const getLocale = (localeKey, locale) => {
    const defaultLocale = locales[localeKey];
    if (!locale) {
        return defaultLocale;
    }
    return deepMerge(defaultLocale, locale);
};
export const en = (locale) => getLocale("en", locale);
export const es = (locale) => getLocale("es", locale);
export const ja = (locale) => getLocale("ja", locale);
export const tl = (locale) => getLocale("tl", locale);
export const tr = (locale) => getLocale("tr", locale);
