import { LocalWallet } from "./LocalWallet";
import { walletIds } from "@thirdweb-dev/wallets";
import { createSecureStorage } from "../../../core/SecureStorage";
import { createAsyncLocalStorage } from "../../../core/AsyncStorage";
/**
 * Wallet config for a Local Wallet
 *
 * @param config - The config for the Local Wallet
 * @returns The wallet config to be used by the ThirdwebProvider
 *
 * @example
 * ```jsx
 * import { ThirdwebProvider, localWallet } from "@thirdweb-dev/react-native";
 *
 * <ThirdwebProvider
 *    supportedWallets={[
 *      localWallet(),
 *    ]}>
 *   <YourApp />
 * </ThirdwebProvider>
 * ```
 */
export const localWallet = () => {
    const secureStorage = createSecureStorage(walletIds.localWallet);
    const asyncStorage = createAsyncLocalStorage(walletIds.localWallet);
    return {
        id: LocalWallet.id,
        meta: LocalWallet.meta,
        create: (options) => new LocalWallet({
            ...options,
            walletStorage: asyncStorage,
            storage: secureStorage,
        }),
    };
};
