import { WalletOptions } from "@thirdweb-dev/react-core";
import { WCMeta } from "../types/wc";
import { WalletConnectBase } from "./wallet-connect/WalletConnectBase";
import { WalletConnectConfig } from "./wallet-connect/wallet-connect";
export declare class MetaMaskWallet extends WalletConnectBase {
    static id: "metamask";
    static meta: {
        name: string;
        iconURL: string;
        links: {
            native: string;
            universal: string;
        };
    };
    getMeta(): WCMeta;
}
/**
 * Wallet config for MetaMask Wallet.
 *
 * @param config - The config for MetamaskWallet
 * @returns The wallet config to be used by the ThirdwebProvider
 *
 * @example
 * ```jsx
 * import { ThirdwebProvider, metamaskWallet } from "@thirdweb-dev/react-native";
 *
 * <ThirdwebProvider
 *    supportedWallets={[metamaskWallet()]}>
 *   <YourApp />
 * </ThirdwebProvider>
 * ```
 */
export declare const metamaskWallet: (config?: WalletConnectConfig) => {
    id: "metamask";
    meta: {
        name: string;
        iconURL: string;
        links: {
            native: string;
            universal: string;
        };
    };
    create: (options: WalletOptions) => MetaMaskWallet;
    recommended: boolean | undefined;
};
