import { walletIds } from "@thirdweb-dev/wallets";
import { WalletConnectBase } from "./wallet-connect/WalletConnectBase";
import { METAMASK_ICON } from "../../assets/svgs";
export class MetaMaskWallet extends WalletConnectBase {
    getMeta() {
        return MetaMaskWallet.meta;
    }
}
MetaMaskWallet.id = walletIds.metamask;
MetaMaskWallet.meta = {
    name: "MetaMask",
    iconURL: METAMASK_ICON,
    links: {
        native: "metamask:",
        universal: "https://metamask.app.link",
    },
};
/**
 * Wallet config for MetaMask Wallet.
 *
 * @param config - The config for MetamaskWallet
 * @returns The wallet config to be used by the ThirdwebProvider
 *
 * @example
 * ```jsx
 * import { ThirdwebProvider, metamaskWallet } from "@thirdweb-dev/react-native";
 *
 * <ThirdwebProvider
 *    supportedWallets={[metamaskWallet()]}>
 *   <YourApp />
 * </ThirdwebProvider>
 * ```
 */
export const metamaskWallet = (config) => {
    return {
        id: MetaMaskWallet.id,
        meta: MetaMaskWallet.meta,
        create: (options) => new MetaMaskWallet({
            ...options,
            walletId: walletIds.metamask,
            projectId: config?.projectId,
        }),
        recommended: config?.recommended,
    };
};
