import { WalletConnectBase } from "./wallet-connect/WalletConnectBase";
import { RAINBOW_ICON } from "../../assets/svgs";
export class RainbowWallet extends WalletConnectBase {
    getMeta() {
        return RainbowWallet.meta;
    }
}
RainbowWallet.id = "rainbow";
RainbowWallet.meta = {
    name: "Rainbow",
    iconURL: RAINBOW_ICON,
    links: {
        native: "rainbow:",
        universal: "https://rnbwapp.com",
    },
};
/**
 * Wallet config for Rainbow Wallet.
 *
 * @param config - The config for RainbowWallet
 * @returns The wallet config to be used by the ThirdwebProvider
 *
 * @example
 * ```jsx
 * import { ThirdwebProvider, rainbowWallet } from "@thirdweb-dev/react-native";
 *
 * <ThirdwebProvider
 *    supportedWallets={[rainbowWallet()]}>
 *   <YourApp />
 * </ThirdwebProvider>
 * ```
 */
export const rainbowWallet = (config) => {
    return {
        id: RainbowWallet.id,
        meta: RainbowWallet.meta,
        create: (options) => new RainbowWallet({
            ...options,
            walletId: RainbowWallet.id,
            projectId: config?.projectId,
        }),
        recommended: config?.recommended,
    };
};
