/// <reference types="react" />
import { ConnectUIProps, type WalletConfig } from "@thirdweb-dev/react-core";
import { SmartWallet } from "@thirdweb-dev/wallets";
import { SmartWalletConfig } from "../types/smart-wallet";
/**
 * Wallet config for Smart Wallet.
 *
 * @param wallet - The EOA wallet config to be connected to the SmartWallet
 * @param config - The config for SmartWallet
 * @returns The wallet config to be used by the ThirdwebProvider
 *
 * @example
 * ```jsx
 * import { ThirdwebProvider, smartWallet, metamaskWallet } from "@thirdweb-dev/react-native";
 *
 * <ThirdwebProvider
 *    supportedWallets={[
 *       smartWallet(metamaskWallet(), {
 *          factoryAddress: 'factory-address',
 *          gasless: true,
 *       }),
 *    ]}>
 *   <YourApp />
 * </ThirdwebProvider>
 * ```
 */
export declare const smartWallet: (wallet: WalletConfig<any>, config: SmartWalletConfig) => WalletConfig<SmartWallet>;
export declare const SmartConnectUI: (props: ConnectUIProps<SmartWallet> & {
    personalWalletConfig: WalletConfig;
}) => import("react").JSX.Element;
