import { WalletConnectBase } from "./wallet-connect/WalletConnectBase";
import { TRUST_ICON } from "../../assets/svgs";
export class TrustWallet extends WalletConnectBase {
    getMeta() {
        return TrustWallet.meta;
    }
}
TrustWallet.id = "trust";
TrustWallet.meta = {
    name: "Trust Wallet",
    iconURL: TRUST_ICON,
    links: {
        native: "trust:",
        universal: "https://link.trustwallet.com",
    },
};
/**
 * Wallet config for Trust Wallet.
 *
 * @param config - The config for TrustWallet
 * @returns The wallet config to be used by the ThirdwebProvider
 *
 * @example
 * ```jsx
 * import { ThirdwebProvider, trustWallet } from "@thirdweb-dev/react-native";
 *
 * <ThirdwebProvider
 *    supportedWallets={[trustWallet()]}>
 *   <YourApp />
 * </ThirdwebProvider>
 * ```
 */
export const trustWallet = (config) => {
    return {
        id: TrustWallet.id,
        meta: TrustWallet.meta,
        create: (options) => new TrustWallet({
            ...options,
            walletId: "trust",
            projectId: config?.projectId,
        }),
        recommended: config?.recommended,
    };
};
