/// <reference types="react" />
import { WalletConfig } from "@thirdweb-dev/react-core";
import { WalletConnect } from "./WalletConnect";
export type WalletConnectConfig = {
    projectId?: string;
    recommended?: boolean;
};
/**
 * Wallet config for WalletConnect.
 *
 * @param config - The config for WalletConnect
 * @returns The wallet config to be used by the ThirdwebProvider
 *
 * @example
 * ```jsx
 * import { ThirdwebProvider, walletConnect } from "@thirdweb-dev/react-native";
 *
 * <ThirdwebProvider
 *    supportedWallets={[walletConnect()]}>
 *   <YourApp />
 * </ThirdwebProvider>
 * ```
 */
export declare const walletConnect: (config?: WalletConnectConfig) => WalletConfig<WalletConnect>;
export type WalletConnectUIProps = {
    /**
     * temporarily hide the ConnectModal
     * This is useful when you want to open another modal and do not want to show the ConnectModal in the background
     */
    hide: () => void;
    /**
     * when the wallet is connected, call this function to indicate that the wallet is connected and it is safe to close the Modal
     */
    connected: () => void;
    /**
     * go back to the wallet selector screen in connect wallet modal
     */
    goBack: () => void;
    /**
     * `WalletConfig` object of the wallet
     */
    walletConfig: WalletConfig<WalletConnect>;
    /**
     * Array of supported wallets including this wallet.
     */
    supportedWallets: WalletConfig[];
    projectId: string;
    isVisible?: boolean;
};
export declare const WalletConnectUI: (props: WalletConnectUIProps) => import("react").JSX.Element;
