import { useAddress, useConnect, useConnectionStatus, useCreateWalletInstance, useSetConnectedWallet, useSetConnectionStatus, useWallet, } from "@thirdweb-dev/react-core";
import { WalletConnect } from "./WalletConnect";
import { WalletConnectInnerUI } from "./WalletConnectInnerUI";
import { TW_WC_PROJECT_ID } from "../../../constants/walletConnect";
import { walletIds } from "@thirdweb-dev/wallets";
/**
 * Wallet config for WalletConnect.
 *
 * @param config - The config for WalletConnect
 * @returns The wallet config to be used by the ThirdwebProvider
 *
 * @example
 * ```jsx
 * import { ThirdwebProvider, walletConnect } from "@thirdweb-dev/react-native";
 *
 * <ThirdwebProvider
 *    supportedWallets={[walletConnect()]}>
 *   <YourApp />
 * </ThirdwebProvider>
 * ```
 */
export const walletConnect = (config) => {
    const projectId = config?.projectId || TW_WC_PROJECT_ID;
    return {
        id: WalletConnect.id,
        meta: WalletConnect.meta,
        create: (options) => new WalletConnect({
            ...options,
            walletId: walletIds.walletConnect,
            projectId,
        }),
        connectUI(props) {
            return <WalletConnectInnerUI {...props} projectId={projectId}/>;
        },
        recommended: config?.recommended,
    };
};
export const WalletConnectUI = (props) => {
    const connect = useConnect();
    const connectionStatus = useConnectionStatus();
    const createWalletInstance = useCreateWalletInstance();
    const setConnectionStatus = useSetConnectionStatus();
    const setConnectedWallet = useSetConnectedWallet();
    const connectedWallet = useWallet();
    const address = useAddress();
    return (<WalletConnectInnerUI {...props} setConnectionStatus={setConnectionStatus} setConnectedWallet={setConnectedWallet} projectId={props.projectId} isVisible={props.isVisible} connect={(connectProps) => connect(props.walletConfig, connectProps)} connectionStatus={connectionStatus} createWalletInstance={() => createWalletInstance(props.walletConfig)} connectedWallet={connectedWallet} connectedWalletAddress={address}/>);
};
